@@ -1,5 +1,5 @@
 package Net::Hadoop::Oozie;
-$Net::Hadoop::Oozie::VERSION = '0.107';
+$Net::Hadoop::Oozie::VERSION = '0.108';
 use 5.010;
 use strict;
 use warnings;
@@ -929,7 +929,7 @@ sub _jobs_iterator {
 
     } while ! $eof && $offset < $total;
 
-    if ( $total_jobs != $total ) {
+    if ( !$shortcircuit && $total_jobs != $total ) {
         warn "Something is wrong, the collected total workflows and the computed total mismatch ($total_jobs != $total)";
     }
 
@@ -950,7 +950,7 @@ Net::Hadoop::Oozie
 
 =head1 VERSION
 
-version 0.107
+version 0.108
 
 =head1 SYNOPSIS
 
